@@ -61,7 +61,7 @@
 #' MCMI(
 #'   fit,
 #'   mi = mi,
-#'   R = 20L, # use a large value e.g., 20000L for actual research
+#'   R = 5L, # use a large value e.g., 20000L for actual research
 #'   alpha = 0.05
 #' )
 #'
@@ -134,12 +134,14 @@ MCMI <- function(lav,
   }
   fits <- lapply(
     X = imp,
-    FUN = function(x) {
+    FUN = function(x,
+                   call1) {
       call1$data <- x
       return(
         eval(expr = call1)
       )
-    }
+    },
+    call1 = call1
   )
   coefs <- lapply(
     X = fits,
