@@ -34,7 +34,7 @@
 #' ## MC() --------------------------------------------------------------------
 #' unstd <- MC(
 #'   fit,
-#'   R = 20L # use a large value e.g., 20000L for actual research
+#'   R = 5L # use a large value e.g., 20000L for actual research
 #' )
 #'
 #' ## Standardized Monte Carlo ------------------------------------------------
@@ -58,7 +58,7 @@
 #' unstd <- MCMI(
 #'   fit,
 #'   mi = mi,
-#'   R = 20L # use a large value e.g., 20000L for actual research
+#'   R = 5L # use a large value e.g., 20000L for actual research
 #' )
 #'
 #' ## Standardized Monte Carlo ------------------------------------------------
@@ -66,7 +66,7 @@
 #' print(unstd)
 #' print(std)
 #'
-#' @keywords method
+#' @keywords methods
 #' @export
 print.semmcci <- function(x,
                           alpha = NULL,
@@ -129,7 +129,7 @@ print.semmcci <- function(x,
 #' ## MC() --------------------------------------------------------------------
 #' unstd <- MC(
 #'   fit,
-#'   R = 20L # use a large value e.g., 20000L for actual research
+#'   R = 5L # use a large value e.g., 20000L for actual research
 #' )
 #'
 #' ## Standardized Monte Carlo ------------------------------------------------
@@ -153,7 +153,7 @@ print.semmcci <- function(x,
 #' unstd <- MCMI(
 #'   fit,
 #'   mi = mi,
-#'   R = 20L # use a large value e.g., 20000L for actual research
+#'   R = 5L # use a large value e.g., 20000L for actual research
 #' )
 #'
 #' ## Standardized Monte Carlo ------------------------------------------------
@@ -161,7 +161,7 @@ print.semmcci <- function(x,
 #' summary(unstd)
 #' summary(std)
 #'
-#' @keywords method
+#' @keywords methods
 #' @export
 summary.semmcci <- function(object,
                             alpha = NULL,
@@ -218,7 +218,7 @@ summary.semmcci <- function(object,
 #' ## MC() --------------------------------------------------------------------
 #' unstd <- MC(
 #'   fit,
-#'   R = 20L # use a large value e.g., 20000L for actual research
+#'   R = 5L # use a large value e.g., 20000L for actual research
 #' )
 #'
 #' ## Standardized Monte Carlo ------------------------------------------------
@@ -242,7 +242,7 @@ summary.semmcci <- function(object,
 #' unstd <- MCMI(
 #'   fit,
 #'   mi = mi,
-#'   R = 20L # use a large value e.g., 20000L for actual research
+#'   R = 5L # use a large value e.g., 20000L for actual research
 #' )
 #'
 #' ## Standardized Monte Carlo ------------------------------------------------
@@ -250,7 +250,7 @@ summary.semmcci <- function(object,
 #' coef(unstd)
 #' coef(std)
 #'
-#' @keywords method
+#' @keywords methods
 #' @export
 coef.semmcci <- function(object,
                          ...) {
@@ -289,7 +289,7 @@ coef.semmcci <- function(object,
 #' ## MC() --------------------------------------------------------------------
 #' unstd <- MC(
 #'   fit,
-#'   R = 20L # use a large value e.g., 20000L for actual research
+#'   R = 5L # use a large value e.g., 20000L for actual research
 #' )
 #'
 #' ## Standardized Monte Carlo ------------------------------------------------
@@ -313,7 +313,7 @@ coef.semmcci <- function(object,
 #' unstd <- MCMI(
 #'   fit,
 #'   mi = mi,
-#'   R = 20L # use a large value e.g., 20000L for actual research
+#'   R = 5L # use a large value e.g., 20000L for actual research
 #' )
 #'
 #' ## Standardized Monte Carlo ------------------------------------------------
@@ -321,7 +321,7 @@ coef.semmcci <- function(object,
 #' vcov(unstd)
 #' vcov(std)
 #'
-#' @keywords method
+#' @keywords methods
 #' @export
 vcov.semmcci <- function(object,
                          ...) {
@@ -366,7 +366,7 @@ vcov.semmcci <- function(object,
 #' ## MC() --------------------------------------------------------------------
 #' unstd <- MC(
 #'   fit,
-#'   R = 20L # use a large value e.g., 20000L for actual research
+#'   R = 5L # use a large value e.g., 20000L for actual research
 #' )
 #'
 #' ## Standardized Monte Carlo ------------------------------------------------
@@ -390,7 +390,7 @@ vcov.semmcci <- function(object,
 #' unstd <- MCMI(
 #'   fit,
 #'   mi = mi,
-#'   R = 20L # use a large value e.g., 20000L for actual research
+#'   R = 5L # use a large value e.g., 20000L for actual research
 #' )
 #'
 #' ## Standardized Monte Carlo ------------------------------------------------
@@ -398,7 +398,7 @@ vcov.semmcci <- function(object,
 #' confint(unstd)
 #' confint(std)
 #'
-#' @keywords method
+#' @keywords methods
 #' @export
 confint.semmcci <- function(object,
                             parm = NULL,
@@ -409,9 +409,14 @@ confint.semmcci <- function(object,
     alpha = 1 - level[1]
   )
   if (is.null(parm)) {
-    parm <- rownames(
+    parameters <- rownames(
       ci
     )
+    if (!is.null(parameters)) {
+      parm <- parameters
+    } else {
+      parm <- seq_len(dim(ci)[1])
+    }
   }
   ci <- ci[parm, 4:5, drop = FALSE]
   varnames <- colnames(ci)
